@@ -19,7 +19,7 @@ use Plack::Util::Accessor qw(
     authenticator
 );
 
-our $VERSION = '0.002005';
+our $VERSION = '0.002006';
 
 sub new {
     my $class         = shift;
@@ -51,11 +51,6 @@ sub new {
         $ui = $config->{ui_class}
             ->new( search_path => $search_path, base_uri => $base_uri );
     }
-    my $admin;
-    if ( $config->{admin_class} ) {
-        load $config->{admin_class};
-        $admin = $config->{admin_class}->new($config);
-    }
 
     load $server_class;
     my $search_server = $server_class->new(
@@ -71,6 +66,17 @@ sub new {
             { %$config, search_path => $search_path }
         ),
     );
+
+    my $admin;
+    if ( $config->{admin_class} ) {
+        load $config->{admin_class};
+        $admin = $config->{admin_class}->app(
+            user_config => $config,
+            searcher    => $search_server,
+            base_uri    => $base_uri,
+        );
+    }
+
     return bless {
         search_path   => $search_path,
         index_path    => $index_path,
